#! /usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Replacement (unofficial) `setup.py` for the `document_page` module.
Automatically generated by `openerpdist`. See http://noteed.com/openerpdist/.
"""

import setuptools

setuptools.setup(
    name = "openerp-document-page",
    version = "7.0.355",
    description = "Document Page",
    long_description = 
"""

Pages
=====
Web pages
    
""",
    url = "http://www.openerp.com/",
    author = "",
    author_email = "TODO",
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Environment :: Plugins",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Natural Language :: English",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    license = "AGPL-3",
    package_dir = {
        'openerp.addons.document_page': ".",
    },
    packages = ["openerp.addons.document_page","openerp.addons.document_page.wizard"],
    package_data = {
        'openerp.addons.document_page': ["i18n/*.po*","document_page_data.xml","document_page_demo.xml","document_page_view.xml","i18n/sk.po","i18n/id.po","i18n/hr.po","i18n/da.po","i18n/sl.po","i18n/es_MX.po","i18n/ru.po","i18n/zh_TW.po","i18n/cs.po","i18n/sq.po","i18n/fi.po","i18n/pt_BR.po","i18n/ko.po","i18n/bg.po","i18n/es_VE.po","i18n/tlh.po","i18n/ja.po","i18n/ro.po","i18n/es_AR.po","i18n/sr@latin.po","i18n/es.po","i18n/mn.po","i18n/it.po","i18n/nl.po","i18n/sv.po","i18n/uk.po","i18n/bs.po","i18n/tr.po","i18n/de.po","i18n/et.po","i18n/sr.po","i18n/lt.po","i18n/hu.po","i18n/vi.po","i18n/el.po","i18n/gl.po","i18n/lv.po","i18n/mk.po","i18n/ca.po","i18n/fr.po","i18n/zh_CN.po","i18n/pl.po","i18n/nl_BE.po","i18n/nb.po","i18n/ar.po","i18n/pt.po","i18n/es_CR.po","test/document_page_test00.yml","security/ir.model.access.csv","security/document_page_security.xml","wizard/document_page_show_diff_view.xml","wizard/document_page_create_menu_view.xml","wizard/document_page_create_menu_view.xml","wizard/document_page_show_diff_view.xml","document_page_view.xml","security/document_page_security.xml","security/ir.model.access.csv","document_page_demo.xml","static/src/css/document_page.css"],
    },
    install_requires = ["openerp-knowledge"],
    tests_require = ["unittest2"],
)
